Graph
=====

.. currentmodule:: pqp.identification

.. autoclass:: Graph
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~Graph.add_edge
      ~Graph.add_edges
      ~Graph.bi_edge_tuples
      ~Graph.di_edge_tuples
      ~Graph.draw
      ~Graph.identify
      ~Graph.identify_ate
      ~Graph.identify_cate

   .. rubric:: Methods Documentation

   .. automethod:: add_edge
   .. automethod:: add_edges
   .. automethod:: bi_edge_tuples
   .. automethod:: di_edge_tuples
   .. automethod:: draw
   .. automethod:: identify
   .. automethod:: identify_ate
   .. automethod:: identify_cate
